@@ -5,8 +5,8 @@
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
 from gitdb import IStream
-from gitdb.util import hex_to_bin
 from git.util import (
+    hex_to_bin,
     Actor,
     Iterable,
     Stats,
@@ -130,7 +130,8 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
             self.parents = parents
         if encoding is not None:
             self.encoding = encoding
-        self.gpgsig = gpgsig
+        if gpgsig is not None:
+            self.gpgsig = gpgsig
 
     @classmethod
     def _get_intermediate_items(cls, commit):
@@ -139,7 +140,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
     def _set_cache_(self, attr):
         if attr in Commit.__slots__:
             # read the data in a chunk, its faster - then provide a file wrapper
-            binsha, typename, self.size, stream = self.repo.odb.stream(self.binsha)
+            binsha, typename, self.size, stream = self.repo.odb.stream(self.binsha)  # @UnusedVariable
             self._deserialize(BytesIO(stream.read()))
         else:
             super(Commit, self)._set_cache_(attr)
@@ -162,7 +163,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         """Count the number of commits reachable from this commit
 
         :param paths:
-            is an optinal path or a list of paths restricting the return value
+            is an optional path or a list of paths restricting the return value
             to commits actually containing the paths
 
         :param kwargs:
@@ -191,7 +192,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         :param repo: is the Repo
         :param rev: revision specifier, see git-rev-parse for viable options
         :param paths:
-            is an optinal path or list of paths, if set only Commits that include the path
+            is an optional path or list of paths, if set only Commits that include the path
             or paths will be considered
         :param kwargs:
             optional keyword arguments to git rev-list where
@@ -266,7 +267,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
             hexsha = line.strip()
             if len(hexsha) > 40:
                 # split additional information, as returned by bisect for instance
-                hexsha, rest = line.split(None, 1)
+                hexsha, _ = line.split(None, 1)
             # END handle extra info
 
             assert len(hexsha) == 40, "Invalid line: %s" % hexsha
@@ -425,10 +426,13 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         if self.encoding != self.default_encoding:
             write(("encoding %s\n" % self.encoding).encode('ascii'))
 
-        if self.gpgsig:
-            write(b"gpgsig")
-            for sigline in self.gpgsig.rstrip("\n").split("\n"):
-                write((" " + sigline + "\n").encode('ascii'))
+        try:
+            if self.__getattribute__('gpgsig') is not None:
+                write(b"gpgsig")
+                for sigline in self.gpgsig.rstrip("\n").split("\n"):
+                    write((" " + sigline + "\n").encode('ascii'))
+        except AttributeError:
+            pass
 
         write(b"\n")
 
@@ -473,6 +477,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         # now we can have the encoding line, or an empty line followed by the optional
         # message.
         self.encoding = self.default_encoding
+        self.gpgsig = None
 
         # read headers
         enc = next_line
